module Config.Pages.Debate.Arguments.Records.UnhealthyRedMeat exposing (..)

import Config.Helpers.Converters exposing (toTitleCase)
import Config.Pages.Debate.Arguments.Types exposing (..)


argumentUnhealthyRedMeat : Argument
argumentUnhealthyRedMeat =
    { argumentTitle = toTitleCase "Argument for Unhealthy Red Meat"
    , propositionTitle = "Red meat and processed meat are  unhealthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, unprocessed red meat has been shown to consistently increase the risk of morbidity and mortality, strongly suggesting that they directly contribute to worse health outcomes, particularly with respect to colorectal cancer and heart disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qm)|=(Pm)"
    , argumentCertainty = 7
    , argumentImage = "redmeat"
    , argumentHashtags = []
   
    
    , isNewTabLink = False
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) has a strong tendency to associate with an increased risk of morbidity and/or mortality after adjusting and/or controlling for relevant variables."
          }
        , { definiendum = "Q(x)"
          , definiens = "there is a dearth of epistemically countervailing data on (x)."
          }
        , { definiendum = "R(x)"
          , definiens = "it is more reasonable to believe that (x) is  unhealthy than it is to believe the opposite."
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "r"
          , definiens = "red meat"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a food has a strong tendency to associate with an increased risk of morbidity and/or mortality after adjusting and/or controling for relevant variables and there is a dearth of epistemically countervailing data on that food, then it is more reasonable to believe that the food is healthy than it is to believe the opposite."
                  , notation = "∀x((Px∧Qx)→Rx)"
                  }
                , { premise = "Red meat has a strong tendency to associate with an increased risk of morbidity and mortality after adjustment and/or controlling for relevant variables."
                  , notation = "Pr"
                  }
                , { premise = "There is a dearth of epistemically countervailing data on red meat."
                  , notation = "Qr"
                  }
                ]
          , conclusion = "Therefore, it is more reasonable to believe that red meat is unhealthy than it is to believe the opposite."
          , conclusionNotation = "Rr"
          }
        ]
    }
